@@ -8,15 +8,16 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.core._jsii
+from typeguard import check_type
+
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@renovosolutions/cdk-aspects-library-security-group",
-    "1.0.98",
+    "2.0.219",
     __name__[0:-6],
-    "cdk-aspects-library-security-group@1.0.98.jsii.tgz",
+    "cdk-aspects-library-security-group@2.0.219.jsii.tgz",
 )
 
 __all__ = [
